@@ -4,13 +4,13 @@ This module is for transforming time series data.
 # Authors: David Burns, Matthias Gazzari, Philip Boyer
 # License: BSD
 
-import numpy as np
 import warnings
+
+import numpy as np
 from scipy.interpolate import interp1d
 from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.exceptions import NotFittedError
-from sklearn.utils import check_random_state, check_array, check_consistent_length, shuffle
-from inspect import signature
+from sklearn.utils import check_random_state, check_array
 from sklearn.utils.metaestimators import _BaseComposition
 
 from .base import TS_Data
@@ -18,7 +18,7 @@ from .feature_functions import base_features
 from .util import get_ts_data_parts, check_ts_data, interp_sort
 
 __all__ = ['Segment', 'SegmentX', 'SegmentXY', 'SegmentXYForecast', 'PadTrunc', 'InterpLongToWide', 'Interp',
-           'FeatureRep', 'FeatureRepMix', 'FunctionTransformer', 'patch_sampler']
+           'FeatureRep', 'FeatureRepMix', 'FunctionTransformer']
 
 
 class XyTransformerMixin(object):
@@ -1441,152 +1441,4 @@ class FunctionTransformer(BaseEstimator, TransformerMixin):
                 raise ValueError("FunctionTransformer changes sample number (not supported).")
             if Xc is not None:
                 Xt = TS_Data(Xt, Xc)
-            return Xt
-
-
-class _InitializePickableSampler(object):
-    """
-    Class for initializing a serialized/pickled and dynamically patched imbalanced-learn Sampler.
-    """
-    def __call__(self, sampler_class):
-        """
-        Recreate a dynamically patched Sampler by creating a _InitializePickableSampler object and
-        turning it into a patched Sampler by using the patch_sampler function.
-        """
-        obj = _InitializePickableSampler()
-        obj.__class__ = patch_sampler(sampler_class)
-        return obj
-
-
-def patch_sampler(sampler_class):
-    """
-    Return a dynamically patched imbalanced-learn Sampler class compatible with Pype.
-    """
-    conditions = [
-        hasattr(sampler_class, 'fit_resample'),
-        hasattr(sampler_class, '_check_X_y'),
-        hasattr(sampler_class, '_get_param_names'),
-    ]
-    if not all(conditions):
-        raise TypeError('The sampler class to be patched must have a "fit_resample", a "_check_X_y"'
-                        ' method and a "_get_param_names" class method.')
-
-    class PickableSampler(sampler_class, XyTransformerMixin):
-        """
-        Dynamically created (pickable) class derived from an imbalanced-learn Sampler and the
-        XyTransformerMixin in order to enable the use of the imbalanced-learn Sampler transforms
-        inside a seglearn Pype.
-
-        Parameters
-        ----------
-        shuffle : boolean, optional (default=False)
-        random_state : int, RandomState instance or None, optional (default=None)
-            seed of the pseudo random number generator used for shuffling the resampled data
-        **kwargs : keyword arguments to be passed to the imbalanced-learn Sampler base class
-
-        Returns
-        -------
-        self : object
-            returns self
-        """
-        def __init__(self, shuffle=False, random_state=None, **kwargs):
-            # set shuffle and random_state
-            self.shuffle = shuffle
-            self.random_state = random_state
-
-            # call imbalanced-learn Sampler base class with the correct arguments
-            orig_signature = signature(super(PickableSampler, self).__init__)
-            orig_args = [p.name for p in orig_signature.parameters.values()
-                         if p.name != 'self' and p.kind != p.VAR_KEYWORD]
-            if "shuffle" in orig_args:
-                kwargs["shuffle"] = shuffle
-            if "random_state" in orig_args:
-                kwargs["random_state"] = random_state
-            super(PickableSampler, self).__init__(**kwargs)
-
-        @classmethod
-        def _get_param_names(cls):
-            """
-            Get parameters of the imbalanced-learn Sampler base class and the additional arguments
-            of the dynamically derived class.
-            """
-            init_signature = signature(getattr(cls, '__init__'))
-            parameters = [p.name for p in init_signature.parameters.values()
-                          if p.name != 'self' and p.kind != p.VAR_KEYWORD]
-            return sorted(set(sampler_class._get_param_names() + parameters))
-
-        def _check_X_y(self, Xt, yt):
-            """
-            Circumvent the check whether dim(Xt) == 2.
-            """
-            Xt_2d = Xt.reshape(Xt.shape[0], -1)
-            _, yt, binarize_yt = super(PickableSampler, self)._check_X_y(Xt_2d, yt)
-            Xt = check_array(Xt, dtype='numeric', ensure_2d=False, allow_nd=True)
-            return Xt, yt, binarize_yt
-
-        def transform(self, X, y=None, sample_weight=None):
-            """
-            Return the given segmented time series data (identity transform) when calling transform
-            without fit on this data (potentially making a prediction) to not alter test data.
-
-            Parameters
-            ----------
-            X : array-like, shape [n_series, ...]
-               time series data and (optionally) contextual data
-            y : array-like, shape [n_series] (default=None)
-                target vector
-            sample_weight : array-like shape [n_series] (default=None)
-                sample weights
-
-            Returns
-            -------
-            X : array-like [n_series, ...]
-            y : array-like [n_series]
-            sample_weight : array-like shape [n_series]
-            """
-            check_ts_data(X, y)
-            return X, y, sample_weight
-
-        def fit_transform(self, X, y, sample_weight=None, **fit_params):
-            """
-            Resample the given segmented time series data based on the Sampler transformer provided
-            as a bass class when calling fit (i.e. not making any prediction on the test data) on
-            this transformer.
-            Sample weights always returned as None.
-
-            Parameters
-            ----------
-            X : array-like, shape [n_series, ...]
-               time series data and (optionally) contextual data
-            y : array-like, shape [n_series] (default=None)
-                target vector
-            sample_weight : array-like shape [n_series] (default=None)
-                sample weights
-            **fit_params : dict of string -> object
-                parameters for the inner imbalanced-learn Sampler object
-
-            Returns
-            -------
-            X : array-like [n_series, ...]
-            y : array-like [n_series]
-            sample_weight : None
-            """
-            check_ts_data(X, y)
-            Xt, Xc = get_ts_data_parts(X)
-            Xt, yt = super(PickableSampler, self).fit_resample(Xt, y, **fit_params)
-            if self.shuffle:
-                Xt, yt = shuffle(Xt, yt, random_state=self.random_state)
-            if Xc is not None:
-                Xt = TS_Data(Xt, Xc)
-            return Xt, yt, None
-
-        def __reduce__(self):
-            """
-            Definition on how to serialize/pickle an object of this dynamically created class.
-            """
-            return _InitializePickableSampler(), (sampler_class,), self.__dict__
-
-    new_class_name = "Patched" + sampler_class.__name__
-    PickableSampler.__name__ = new_class_name
-    PickableSampler.__qualname__ = new_class_name
-    return PickableSampler
+            return Xt
\ No newline at end of file
